#
# spec file for package python-azure-mgmt-billing
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define realversion 6.0.0

%{?sle15_python_module_pythons}
Name:           python-azure-mgmt-billing
Version:        6.0.0.0
Release:        150400.14.3.1
Summary:        Microsoft Azure Billing Client Library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-mgmt-billing/azure-mgmt-billing-%{realversion}.zip
Source1:        LICENSE.txt
BuildRequires:  %{python_module azure-mgmt-nspkg >= 3.0.0}
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-azure-mgmt-nspkg >= 3.0.0
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-msrest >= 0.6.21
Requires:       (python-azure-common >= 1.1 with python-azure-common < 2.0.0)
Requires:       (python-azure-mgmt-core >= 1.2.0 with python-azure-mgmt-core < 2.0.0)
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-mgmt-billing < 6.0.0.0
%endif
BuildArch:      noarch

%python_subpackages

%description
This is the Microsoft Azure Billing Client Library.

Azure Resource Manager (ARM) is the next generation of management APIs that
replace the old Azure Service Management (ASM).

This package has been tested with Python 2.7, 3.4, 3.5 and 3.6.

%prep
%setup -q -n azure-mgmt-billing-%{realversion}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-mgmt-billing-%{realversion}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/mgmt/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/mgmt/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{python_sitelib}/azure/mgmt/billing
%{python_sitelib}/azure_mgmt_billing-*.dist-info

%changelog
* Thu Apr  4 2024 adrian.glaubitz@suse.com
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
- Use modern RPM macros to express version dependencies
* Thu Nov 24 2022 adrian.glaubitz@suse.com
- New upstream release
  + Version 6.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Override upstream version with 6.0.0.0 to ensure
  proper upgrade from previous version 6.0.0b1
- Update Requires from setup.py
* Fri Dec 18 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 6.0.0b1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Thu Nov 26 2020 rjschwei@suse.com
- Only build Python3 flavors for distributions 15 and greater
* Fri Nov 20 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.0.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Fri Oct  4 2019 adrian.glaubitz@suse.com
- Drop patch to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + amb_drop-compatible-releases-operator.patch
* Thu Apr 11 2019 adrian.glaubitz@suse.com
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
* Wed Apr 11 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.2.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Move LICENSE.txt from %%doc to %%license section
- Refresh patches for new version
  + amb_drop-compatible-releases-operator.patch
- Update Requires from setup.py
- Update %%description and Summary from setup.py
* Mon Jan 29 2018 adrian.glaubitz@suse.com
- Install HISTORY.rst into doc directory
* Fri Nov  3 2017 adrian.glaubitz@suse.com
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + amb_drop-compatible-releases-operator.patch
* Mon Oct  9 2017 adrian.glaubitz@suse.com
- Remove versioning for namespace packages in Requires
- Add namespace packages to BuildRequires
- Remove namespace files in %%install target
- Explicitly specify Python files of the package in %%files
* Tue Sep 12 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 0.1.0
